AshJason.Protocol protocol (ash_jason v3.1.0)
View SourceA protocol that provides a way to get fields from a record using AshJason's logic.
Summary
Types
@type t() :: term()
All the types that implement this protocol.
A protocol that provides a way to get fields from a record using AshJason's logic.
@type t() :: term()
All the types that implement this protocol.